=========
blpdecode
=========


.. image:: https://img.shields.io/github/license/rstms/blpdecode
        :alt: GitHub

.. image:: https://img.shields.io/pypi/v/blpdecode.svg
        :target: https://pypi.python.org/pypi/blpdecode


.. image:: https://circleci.com/gh/rstms/blpdecode/tree/master.svg?style=shield
        :target: https://circleci.com/gh/rstms/blpdecode/tree/master

.. image:: https://readthedocs.org/projects/blpdecode/badge/?version=latest
        :target: https://blpdecode.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/rstms/blpdecode/shield.svg
     :target: https://pyup.io/repos/github/rstms/blpdecode/
     :alt: Updates

Barracuda LinkProtect Decoder


* Free software: MIT license
* Documentation: https://blpdecode.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and `rstms/cookiecutter-python-cli`, a fork of the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _`rstms/cookiecutter-python-cli`: https://github.com/rstms/cookiecutter-python-cli
